@@ -57,7 +57,7 @@
 **        each copy of the program.
 */
 
-/* 
+/*
  * Contains the structures and function APIs for ISO9660 file system support.
  */
 
@@ -97,6 +97,7 @@
 
 #define ISO9660_MAXNAMLEN_STD	128     ///< Maximum length of standard name
 #define ISO9660_MAXNAMLEN_JOL   128     ///< maximum UTF-16 joliet name (in bytes)
+#define ISO9660_MAXNAMLEN_RR    256     ///< Maximum length of a Rock Ridge extension name
 #define ISO9660_MAXNAMLEN   (ISO9660_MAXNAMLEN_JOL << 1)        // mult jol by 2 to account for UTF-16 to UTF-8 conversion
 
 /* Bits in permissions used in extended attribute records.  */
@@ -201,9 +202,9 @@ typedef struct {
 
 /* generic volume descriptor */
 typedef struct {
-    uint8_t type;               ///<  volume descriptor type 
-    char magic[ISODCL(2, 6)];   ///< magic number. "CD001" 
-    char ver[ISODCL(7, 7)];     ///< volume descriptor version 
+    uint8_t type;               ///<  volume descriptor type
+    char magic[ISODCL(2, 6)];   ///< magic number. "CD001"
+    char ver[ISODCL(7, 7)];     ///< volume descriptor version
     char x[ISODCL(8, 2048)];    ///< Depends on descriptor type
 } iso9660_gvd;
 
@@ -351,7 +352,7 @@ typedef struct {
     TSK_GID_T gid;              /* group */
     uint16_t mode;              /* posix file mode */
     uint32_t nlink;             /* number of links */
-    char fn[ISO9660_MAXNAMLEN_STD];     /* alternate filename */
+    char fn[ISO9660_MAXNAMLEN_RR];     /* alternate filename */
 } rockridge_ext;
 
 /** \internal
@@ -385,13 +386,13 @@ typedef struct {
     uint32_t path_tab_addr;     /* address of path table */
     uint32_t root_addr;         /* address of root dir extent */
     iso9660_pvd_node *pvd;      ///< Head of primary volume descriptor list (there should be only one...)
-    iso9660_svd_node *svd;      ///< Head of secondary volume descriptor list 
+    iso9660_svd_node *svd;      ///< Head of secondary volume descriptor list
     iso9660_inode_node *in_list;        /* list of inodes */
     uint8_t rr_found;           /* 1 if rockridge found */
 } ISO_INFO;
 
 extern TSK_RETVAL_ENUM iso9660_dir_open_meta(TSK_FS_INFO * a_fs,
-    TSK_FS_DIR ** a_fs_dir, TSK_INUM_T a_addr);
+    TSK_FS_DIR ** a_fs_dir, TSK_INUM_T a_addr, int recursion_depth);
 
 extern uint8_t iso9660_dinode_load(ISO_INFO * iso, TSK_INUM_T inum,
     iso9660_inode * dinode);
@@ -445,7 +446,7 @@ typedef struct {
     uint8_t len_id;             ///< length of extension id (in bytes)
     uint8_t len_des;            ///< length of extension desc (in bytes)
     uint8_t len_src;            ///< Length of extension spec source (in bytes)
-    uint8_t ext_ver;            ///< Version id 
+    uint8_t ext_ver;            ///< Version id
     char ext_id[1];             ///< Extension ID text (with length of len_id);
     // next is the extension descriptor text
     // next is the extension source text
